@@ -2,7 +2,7 @@
 // detail/config.hpp
 // ~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2024 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2025 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -373,10 +373,20 @@
 #  if (__cplusplus >= 201703)
 #   if defined(__clang__)
 #    if defined(BOOST_ASIO_HAS_CLANG_LIBCXX)
-#     if (_LIBCPP_STD_VER > 14) && defined(_LIBCPP_HAS_ALIGNED_ALLOC) \
-        && !defined(_LIBCPP_MSVCRT) && !defined(__MINGW32__)
-#      if defined(__ANDROID__) && (__ANDROID_API__ >= 28)
+#     if (_LIBCPP_STD_VER > 14)
+#      if defined(__FreeBSD__) || defined(__Fuchsia__) || defined(__wasi__) \
+         || defined(__NetBSD__) || defined(__OpenBSD__)
+#       define BOOST_ASIO_HAS_STD_ALIGNED_ALLOC 1
+#      elif defined(__linux__)
+#       if defined(_LIBCPP_HAS_MUSL_LIBC)
 #        define BOOST_ASIO_HAS_STD_ALIGNED_ALLOC 1
+#       else // !defined(_LIBCPP_HAS_MUSL_LIBC)
+#        if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 17)
+#         define BOOST_ASIO_HAS_STD_ALIGNED_ALLOC 1
+#        endif // (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 17)
+#       endif // !defined(_LIBCPP_HAS_MUSL_LIBC)
+#      elif defined(__ANDROID__) && (__ANDROID_API__ >= 28)
+#       define BOOST_ASIO_HAS_STD_ALIGNED_ALLOC 1
 #      elif defined(__APPLE__)
 #       if defined(__MAC_OS_X_VERSION_MIN_REQUIRED)
 #        if (__MAC_OS_X_VERSION_MIN_REQUIRED >= 101500)
@@ -395,11 +405,8 @@
 #         define BOOST_ASIO_HAS_STD_ALIGNED_ALLOC 1
 #        endif // (__WATCH_OS_VERSION_MIN_REQUIRED >= 60000)
 #       endif // defined(__WATCH_OS_X_VERSION_MIN_REQUIRED)
-#      else // defined(__APPLE__)
-#       define BOOST_ASIO_HAS_STD_ALIGNED_ALLOC 1
 #      endif // defined(__APPLE__)
-#     endif // (_LIBCPP_STD_VER > 14) && defined(_LIBCPP_HAS_ALIGNED_ALLOC)
-            //   && !defined(_LIBCPP_MSVCRT) && !defined(__MINGW32__)
+#     endif // (_LIBCPP_STD_VER > 14)
 #    elif defined(_GLIBCXX_HAVE_ALIGNED_ALLOC)
 #     define BOOST_ASIO_HAS_STD_ALIGNED_ALLOC 1
 #    endif // defined(_GLIBCXX_HAVE_ALIGNED_ALLOC)
@@ -439,13 +446,6 @@
 # endif // !defined(BOOST_ASIO_DISABLE_BOOST_DATE_TIME)
 #endif // !defined(BOOST_ASIO_HAS_BOOST_DATE_TIME)
 
-// Boost support for the Coroutine library.
-#if !defined(BOOST_ASIO_HAS_BOOST_COROUTINE)
-# if !defined(BOOST_ASIO_DISABLE_BOOST_COROUTINE)
-#  define BOOST_ASIO_HAS_BOOST_COROUTINE 1
-# endif // !defined(BOOST_ASIO_DISABLE_BOOST_COROUTINE)
-#endif // !defined(BOOST_ASIO_HAS_BOOST_COROUTINE)
-
 // Boost support for the Context library's fibers.
 #if !defined(BOOST_ASIO_HAS_BOOST_CONTEXT_FIBER)
 # if !defined(BOOST_ASIO_DISABLE_BOOST_CONTEXT_FIBER)
@@ -607,7 +607,9 @@
 // Standard library support for std::source_location.
 #if !defined(BOOST_ASIO_HAS_STD_SOURCE_LOCATION)
 # if !defined(BOOST_ASIO_DISABLE_STD_SOURCE_LOCATION)
-// ...
+#  if (__cpp_lib_source_location >= 201907)
+#   define BOOST_ASIO_HAS_STD_SOURCE_LOCATION 1
+#  endif // (__cpp_lib_source_location >= 201907)
 # endif // !defined(BOOST_ASIO_DISABLE_STD_SOURCE_LOCATION)
 #endif // !defined(BOOST_ASIO_HAS_STD_SOURCE_LOCATION)
 
@@ -832,11 +834,13 @@
 #  endif // !defined(BOOST_ASIO_DISABLE_EVENTFD)
 # endif // !defined(BOOST_ASIO_HAS_EVENTFD)
 # if !defined(BOOST_ASIO_HAS_TIMERFD)
-#  if defined(BOOST_ASIO_HAS_EPOLL)
-#   if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 8)
-#    define BOOST_ASIO_HAS_TIMERFD 1
-#   endif // (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 8)
-#  endif // defined(BOOST_ASIO_HAS_EPOLL)
+#  if !defined(BOOST_ASIO_DISABLE_TIMERFD)
+#   if defined(BOOST_ASIO_HAS_EPOLL)
+#    if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 8)
+#     define BOOST_ASIO_HAS_TIMERFD 1
+#    endif // (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 8)
+#   endif // defined(BOOST_ASIO_HAS_EPOLL)
+#  endif // !defined(BOOST_ASIO_DISABLE_TIMERFD)
 # endif // !defined(BOOST_ASIO_HAS_TIMERFD)
 # if defined(BOOST_ASIO_HAS_IO_URING)
 #  if LINUX_VERSION_CODE < KERNEL_VERSION(5,10,0)
@@ -1370,6 +1374,24 @@
 # define BOOST_ASIO_NODISCARD
 #endif // !defined(BOOST_ASIO_NODISCARD)
 
+// Compiler support for the the [[deprecated(msg)]] attribute.
+#if !defined(BOOST_ASIO_DEPRECATED_MSG)
+# if !defined(BOOST_ASIO_DISABLE_DEPRECATED_MSG)
+#  if defined(BOOST_ASIO_MSVC) && (BOOST_ASIO_MSVC >= 1400)
+#   define BOOST_ASIO_DEPRECATED_MSG(msg) __declspec(deprecated(msg))
+#  elif (__cplusplus >= 201402)
+#   if defined(__has_cpp_attribute)
+#    if __has_cpp_attribute(deprecated)
+#     define BOOST_ASIO_DEPRECATED_MSG(msg) [[deprecated(msg)]]
+#    endif // __has_cpp_attribute(deprecated)
+#   endif // defined(__has_cpp_attribute)
+#  endif // __cplusplus >= 201402
+# endif // !defined(BOOST_ASIO_DISABLE_DEPRECATED_MSG)
+#endif // !defined(BOOST_ASIO_DEPRECATED_MSG)
+#if !defined(BOOST_ASIO_DEPRECATED_MSG)
+# define BOOST_ASIO_DEPRECATED_MSG(msg)
+#endif // !defined(BOOST_ASIO_DEPRECATED_MSG)
+
 // Kernel support for MSG_NOSIGNAL.
 #if !defined(BOOST_ASIO_HAS_MSG_NOSIGNAL)
 # if defined(__linux__)
